# -*- coding: utf-8 -*-
# @Time    : 2021/9/30 16:59 
# @Author  : xzr
# @File    : conf.py
# @Software: PyCharm
# @Contact : xzregg@gmail.com
# @Desc    :

from django.conf import settings
from dynamic_settings.conf import *